"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.signMessage = signMessage;
var _codec = require("@ckb-lumos/codec");
var _bytes = require("@ckb-lumos/codec/lib/bytes");
const COMMON_PREFIX = "CKB transaction: 0x";
async function signMessage(address, digest, provider) {
  /* c8 ignore start */
  const internal = provider !== null && provider !== void 0 ? provider : globalThis.ethereum;
  if (!internal) {
    throw new Error("No provider found, make sure you have installed MetaMask or the other EIP1193 compatible wallet");
  }
  /* c8 ignore end */

  const sig = await internal.request({
    method: "personal_sign",
    params: [address, `${COMMON_PREFIX}${(0, _bytes.hexify)(digest).slice(2)}`]
  });
  const signature = _codec.bytes.bytify(sig);
  const [tweakedV] = signature.slice(-1);
  // https://eips.ethereum.org/EIPS/eip-155
  const PARITY_FLAG = 27;
  const v = tweakedV >= PARITY_FLAG ? tweakedV - PARITY_FLAG : tweakedV;
  signature.set([v], signature.length - 1);
  return _codec.bytes.hexify(signature);
}
//# sourceMappingURL=omnilock-ethereum-displaying.js.map